nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Csw

Struct Csw 

#[repr(transparent)]
pub struct Csw(pub u32);
CRC mode register

Tuple Fields

0: u32

Implementations

Source

impl Csw

pub const fn resynch_req(&self) -> bool

Debugger will set this bit to 1 to request a resynchronrisation

pub const fn set_resynch_req(&mut self, val: bool)

Debugger will set this bit to 1 to request a resynchronrisation

pub const fn req_pending(&self) -> bool

Request is pending from debugger (i.e unread value in REQUEST)

pub const fn set_req_pending(&mut self, val: bool)

Request is pending from debugger (i.e unread value in REQUEST)

pub const fn dbg_or_err(&self) -> bool

Debugger overrun error (previous REQUEST overwritten before being picked up by ROM)

pub const fn set_dbg_or_err(&mut self, val: bool)

Debugger overrun error (previous REQUEST overwritten before being picked up by ROM)

pub const fn ahb_or_err(&self) -> bool

AHB overrun Error (Return value overwritten by ROM)

pub const fn set_ahb_or_err(&mut self, val: bool)

AHB overrun Error (Return value overwritten by ROM)

pub const fn soft_reset(&self) -> bool

Soft Reset for DM (write-only from AHB, not readable and selfclearing). A write to this bit will cause a soft reset for DM.

pub const fn set_soft_reset(&mut self, val: bool)

Soft Reset for DM (write-only from AHB, not readable and selfclearing). A write to this bit will cause a soft reset for DM.

pub const fn chip_reset_req(&self) -> bool

Write only bit. Once written will cause the chip to reset (note that the DM is not reset by this reset as it is only resettable by a SOFT reset or a POR/BOD event)

pub const fn set_chip_reset_req(&mut self, val: bool)

Write only bit. Once written will cause the chip to reset (note that the DM is not reset by this reset as it is only resettable by a SOFT reset or a POR/BOD event)